==> servicecatalog-0.21.0-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnCloudFormationProvisionedProduct.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-cloudformationprovisionedproduct.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:54.808Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.CfnCloudFormationProvisionedProduct")
public class CfnCloudFormationProvisionedProduct extends software.amazon.awscdk.Resource {
    protected CfnCloudFormationProvisionedProduct(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProduct.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CfnCloudFormationProvisionedProduct`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CfnCloudFormationProvisionedProduct``
     */
    public CfnCloudFormationProvisionedProduct(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param parent the ``cdk.Construct`` this ``CfnCloudFormationProvisionedProduct`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public CfnCloudFormationProvisionedProduct(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute CloudformationStackArn
     */
    public java.lang.String getCloudFormationProvisionedProductCloudformationStackArn() {
        return this.jsiiGet("cloudFormationProvisionedProductCloudformationStackArn", java.lang.String.class);
    }

    public java.lang.String getCloudFormationProvisionedProductId() {
        return this.jsiiGet("cloudFormationProvisionedProductId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute RecordId
     */
    public java.lang.String getCloudFormationProvisionedProductRecordId() {
        return this.jsiiGet("cloudFormationProvisionedProductRecordId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html
     */
    public static interface ProvisioningParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        java.lang.Object getKey();
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final software.amazon.awscdk.Token value);
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        java.lang.Object getValue();
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final java.lang.String value);
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link ProvisioningParameterProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ProvisioningParameterProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _key;
            @javax.annotation.Nullable
            private java.lang.Object _value;

            /**
             * Sets the value of Key
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Key
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ProvisioningParameterProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ProvisioningParameterProperty build() {
                return new ProvisioningParameterProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.Object $value = _value;

                    @Override
                    public java.lang.Object getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getKey() {
                return this.jsiiGet("key", java.lang.Object.class);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("value", value);
            }
        }
    }
}

==> servicecatalog-0.22.0-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnCloudFormationProvisionedProduct.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-cloudformationprovisionedproduct.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.13 (build 311bf88)", date = "2019-01-11T10:47:29.752Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.CfnCloudFormationProvisionedProduct")
public class CfnCloudFormationProvisionedProduct extends software.amazon.awscdk.Resource {
    protected CfnCloudFormationProvisionedProduct(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProduct.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnCloudFormationProvisionedProduct(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::CloudFormationProvisionedProduct``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     */
    public CfnCloudFormationProvisionedProduct(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute CloudformationStackArn
     */
    public java.lang.String getCloudFormationProvisionedProductCloudformationStackArn() {
        return this.jsiiGet("cloudFormationProvisionedProductCloudformationStackArn", java.lang.String.class);
    }

    public java.lang.String getCloudFormationProvisionedProductId() {
        return this.jsiiGet("cloudFormationProvisionedProductId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute RecordId
     */
    public java.lang.String getCloudFormationProvisionedProductRecordId() {
        return this.jsiiGet("cloudFormationProvisionedProductRecordId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProductProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html
     */
    public static interface ProvisioningParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        java.lang.String getKey();
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        java.lang.String getValue();
        /**
         * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
         */
        void setValue(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link ProvisioningParameterProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ProvisioningParameterProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.String _key;
            @javax.annotation.Nullable
            private java.lang.String _value;

            /**
             * Sets the value of Key
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ProvisioningParameterProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ProvisioningParameterProperty build() {
                return new ProvisioningParameterProperty() {
                    @javax.annotation.Nullable
                    private java.lang.String $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.String $value = _value;

                    @Override
                    public java.lang.String getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.String getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getKey() {
                return this.jsiiGet("key", java.lang.String.class);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getValue() {
                return this.jsiiGet("value", java.lang.String.class);
            }

            /**
             * ``CfnCloudFormationProvisionedProduct.ProvisioningParameterProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-servicecatalog-cloudformationprovisionedproduct-provisioningparameter.html#cfn-servicecatalog-cloudformationprovisionedproduct-provisioningparameter-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }
        }
    }
}
